@@ -13,13 +13,25 @@ class FormulaicWarning(Warning):
 
 
 class FormulaInvalidError(FormulaicError):
+    """
+    Provided formula specification is not a valid format.
+    """
     pass
 
 
 class FormulaParsingError(FormulaicError):
+    """
+    An error occured during the parsing of a formula specification.
+    """
     pass
 
 
+class FormulaSyntaxError(FormulaParsingError):
+    """
+    Could not tokenize the nominated formula specification.
+    """
+    pass
+
 # Formula materializer meta-errors
 
 
