@@ -5,16 +5,33 @@ from .term import Term
 
 class Factor:
 
-    class Kind(Enum):
-        NAME = 'name'
-        VALUE = 'value'
+    class EvalMethod(Enum):
+        UNKNOWN = 'unknown'
+        LITERAL = 'literal'
+        LOOKUP = 'lookup'
         PYTHON = 'python'
 
-    __slots__ = ('expr', '_kind')
+    class Kind(Enum):
+        UNKNOWN = 'unknown'
+        CONSTANT = 'constant'
+        NUMERICAL = 'numerical'
+        CATEGORICAL = 'categorical'
 
-    def __init__(self, expr='', *, kind=None):
+    __slots__ = ('expr', '_eval_method', '_kind', 'metadata')
+
+    def __init__(self, expr='', *, eval_method=None, kind=None, metadata=None):
         self.expr = expr
+        self.eval_method = eval_method
         self.kind = kind
+        self.metadata = metadata or {}
+
+    @property
+    def eval_method(self):
+        return self._eval_method
+
+    @eval_method.setter
+    def eval_method(self, eval_method):
+        self._eval_method = Factor.EvalMethod(eval_method or 'unknown')
 
     @property
     def kind(self):
@@ -22,7 +39,7 @@ class Factor:
 
     @kind.setter
     def kind(self, kind):
-        self._kind = self.Kind(kind) if kind else kind
+        self._kind = Factor.Kind(kind or 'unknown')
 
     def __eq__(self, other):
         if isinstance(other, str):
